from .connection_check import connection_check
from bs4 import BeautifulSoup
from requests import get
from sys import exit

class ip:
    def __init__(self):
        if connection_check() == False:
            print("please turn on your internet :|")
            exit()
        response = get("https://browserleaks.com/ip").text
        html = BeautifulSoup(response, "html.parser")
        self.ip = html.find_all("span", {"class":"flag-text wball"})[0].text
        self.region = html.find_all("tbody")[0].find_all("tr")[5].find_all("td")[1].text
        self.city = html.find_all("tbody")[0].find_all("tr")[6].find_all("td")[1].text
        self.isp = html.find_all("tbody")[0].find_all("tr")[7].find_all("td")[1].text
        self.organization = html.find_all("tbody")[0].find_all("tr")[8].find_all("td")[1].text
        self.network = html.find_all("tbody")[0].find_all("tr")[9].find_all("td")[1].text
        self.usage_type = html.find_all("tbody")[0].find_all("tr")[10].find_all("td")[1].text
        self.timezone = html.find_all("tbody")[0].find_all("tr")[11].find_all("td")[1].text
        self.local_time = html.find_all("tbody")[0].find_all("tr")[12].find_all("td")[1].text
        self.coordinates = html.find_all("tbody")[0].find_all("tr")[13].find_all("td")[1].text
        self.os = html.find_all("tbody")[3].find_all("tr")[1].find_all("td")[1].text



from requests import get, ConnectionError

def connection_check():
    try:
        response = get("http://www.google.com", timeout=5)
        if response.status_code == 200:
            return True
        else:
            return False
    except ConnectionError:
        return False



from setuptools import setup, find_packages

setup(
    name = 'goodip',
    version = '0.0.2',
    author= 'Erfan Bafandeh',
    author_email = 'user.enbh@gmail.com',
    description = 'you can get your ip address and get its information.',
    keywords = ['ip', 'myip', 'goodip', 'checkip'],
    long_description = open("README.md", encoding="utf-8").read(),
    python_requires="~=3.6",
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/Erfan-Bafandeh/goodip',
    packages = find_packages(),
    install_requires = ["requests", "colorama", "beautifulsoup4"],
    classifiers = [
    	"Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "License :: OSI Approved :: MIT License",
    ]
)



from .ip import ip

__title__: str = 'goodip'
__version__: str = '0.0.1'
__license__: str = 'MIT license'
__author__: str = 'Erfan Bafandeh'
__url__: str = 'https://github.com/Erfan-Bafandeh/goodip'
__author_email__: str = 'user.enbh@gmail.com'
__description__: str = 'you can get your ip address and get its information.'